<?php
/**
 * @package     VikBooking
 * @subpackage  com_vikbooking
 * @author      E4J srl
 * @copyright   Copyright (C) 2022 E4J srl. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 * @link        https://vikwp.com
 */

defined('ABSPATH') or die('No script kiddies please!');

class VikBookingCronJobFooBarBaz extends VBOCronJob
{
	use VBOCronTrackerArray;

	/**
	 * This method should return all the form fields required to collect the information
	 * needed for the execution of the cron job.
	 * 
	 * @return  array  An associative array of form fields.
	 */
	public function getForm()
	{
		return [
			'cron_lbl' => [
				'type'  => 'custom',
				'label' => '',
				'html'  => '<h4><i class="far fa-file-archive"></i>&nbsp;<i class="far fa-clock"></i>&nbsp;' . $this->getTitle() . '</h4>',
			],
			'maxchars' => [
				'type' => 'number',
				'label' => 'Maximum Characters',
				'help' => 'The maximum number of characters that can be stored within the list of processed elements.',
				'default' => 100,
				'min' => 0,
				'step' => 1,
			],
			'help' => [
				'type'  => 'custom',
				'label' => '',
				'html'  => '<p class="vbo-cronparam-suggestion"><i class="vboicn-lifebuoy"></i>Sample driver used to test the cron jobs extendability.</p>',
			],
		];
	}

	/**
	 * Returns the title of the cron job.
	 * 
	 * @return  string
	 */
	public function getTitle()
	{
		return 'Foo Bar - Baz';
	}
	
	/**
	 * Executes the cron job.
	 * 
	 * @return  boolean  True on success, false otherwise.
	 */
	protected function execute()
	{
		$this->maximumCharsTrackableElements = $this->params->get('maxchars', 100);
		
		$n = rand(0, 5);

		$this->appendLog("Registering [$n] numbers...");

		for ($i = 1; $i <= $n; $i++)
		{
			$elem = rand(0, 100);
			$result = $this->track($elem);
			$this->appendLog("Tracking element [$elem]: " . ($result ? 'Y' : 'N'));
		}

		if ($this->isDebug())
		{
			$dump = clone $this->getData();
			unset($dump->logs);
			echo '<pre>' . print_r($dump, true) . '</pre>';
		}

		return true;
	}
}
