<?php
/**
 * @package     VikBooking
 * @subpackage  com_vikbooking
 * @author      E4J srl
 * @copyright   Copyright (C) 2022 E4J srl. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 * @link        https://vikwp.com
 */

defined('ABSPATH') or die('No script kiddies please!');

class VikBookingCronJobStressTest extends VBOCronJob
{
	use VBOCronTrackerUnused;
	
	/**
	 * This method should return all the form fields required to collect the information
	 * needed for the execution of the cron job.
	 * 
	 * @return  array  An associative array of form fields.
	 */
	public function getForm()
	{
		return [
			'cron_lbl' => [
				'type'  => 'custom',
				'label' => '',
				'html'  => '<h4><i class="far fa-file-archive"></i>&nbsp;<i class="far fa-clock"></i>&nbsp;' . $this->getTitle() . '</h4>',
			],
			'numlogs' => [
				'type'    => 'number',
				'label'   => 'Logs Number',
				'help'    => 'Enter the number of logs to register.',
				'default' => 100,
				'min'     => 0,
				'step'    => 1,
			],
			'help' => [
				'type'  => 'custom',
				'label' => '',
				'html'  => '<p class="vbo-cronparam-suggestion"><i class="vboicn-lifebuoy"></i>Performs some stress tests.</p>',
			],
		];
	}

	/**
	 * Returns the title of the cron job.
	 * 
	 * @return  string
	 */
	public function getTitle()
	{
		return 'Stress - Tester';
	}
	
	/**
	 * Executes the cron job.
	 * 
	 * @return  boolean  True on success, false otherwise.
	 */
	protected function execute()
	{
		$this->setLog('<div style="white-space: break-spaces;">1');

		for ($i = 2; $i <= (int) $this->params->get('numlogs', 100); $i++)
		{
			$this->appendLog($i, "\t");
		}

		$this->appendLog('</div>');

		return true;
	}
}
